@@ -8,7 +8,7 @@ use vars qw( @ISA );
 @ISA = qw( HTTP::Proxy::HeaderFilter );
 
 # known hop-by-hop headers
-my %hopbyhop = map { $_ => 1 }
+my @hopbyhop = 
   qw( Connection Keep-Alive Proxy-Authenticate Proxy-Authorization
       TE Trailers Transfer-Encoding Upgrade Proxy-Connection Public );
 
@@ -32,10 +32,10 @@ sub filter {
       if $message->isa( 'HTTP::Request' ) && $self->proxy->x_forwarded_for;
 
     # make a list of hop-by-hop headers
-    my %h2h = %hopbyhop;
+    my %h2h = map { (lc) => 1 } @hopbyhop;
     my $hop = HTTP::Headers->new();
     my $client = HTTP::Headers->new();
-    $h2h{ $_->[0] } = 1
+    $h2h{ lc $_->[0] } = 1
       for map { split_header_words($_) } $headers->header('Connection');
 
     # hop-by-hop headers are set aside
@@ -43,7 +43,7 @@ sub filter {
     $headers->scan(
         sub {
             my ( $k, $v ) = @_;
-            if ( $h2h{$k} ) {
+            if ( $h2h{lc $k} ) {
                 $hop->push_header( $k => $v );
                 $headers->remove_header($k);
             }
@@ -93,7 +93,6 @@ sub filter {
         # no encoding accepted (gzip, compress, deflate)
         qw( Accept-Encoding ),
     );
-
 }
 
 1;
@@ -106,9 +105,27 @@ HTTP::Proxy::HeaderFilter::standard - An internal filter to respect RFC2616
 
 =head1 DESCRIPTION
 
-This is an internal filter used by HTTP::Proxy.
+This is an internal filter used by HTTP::Proxy to enforce behaviour
+compliant with RFC 2616.
 
-Move along, nothing to see here.
+=head1 METHOD
+
+This filter implements a single method that is called automatically:
+
+=over 4
+
+=item filter()
+
+Enforce RFC 2616-compliant behaviour, by adding the C<Via:> and
+C<X-Forwarded-For:> headers (except when the proxy was instructed not
+to add them), decrementing the C<Max-Forwards:> header and removing
+the hop-by-hop and LWP::UserAgent headers.
+
+=back
+
+=head1 SEE ALSO
+
+L<HTTP::Proxy>, L<HTTP::Proxy::HeaderFilter>, RFC 2616.
 
 =head1 AUTHOR
 
@@ -119,7 +136,7 @@ hop-by-hop headers.
 
 =head1 COPYRIGHT
 
-Copyright 2003-2004, Philippe Bruhat
+Copyright 2003-2005, Philippe Bruhat.
 
 =head1 LICENSE
 
